multidim.models.GaussianMixtureClassifier — GDA Toolbox v1.0 Manual

# multidim.models.GaussianMixtureClassifier

class `multidim.models.` `GaussianMixtureClassifier`(stop_level=None, **kwargs)

  A scikit-learn classification estimator, for any sort of Gaussian mixture model.

  A Gaussian mixture module is a collection of labelled Gaussian functions

  This is provided mainly to provide a parent class for `CDER`.

  `GaussianMixtureClassifier.evaluate`(x) | Evaluate all gaussians against a pointcloud
  `GaussianMixtureClassifier.fit`(*training) | Fit this estimator to training data.
  `GaussianMixtureClassifier.gausscoords`() | This is the method to overwrite for specific models!
  `GaussianMixtureClassifier.get_params`([deep]) | Pass original kwargs internally.
  `GaussianMixtureClassifier.plot`(canvas[, style]) | Plot a CDER model, using matplotlib or bokeh
  `GaussianMixtureClassifier.predict`(pointclouds) | Predict labels of given pointclouds, based on previous training data fed to `fit()`.
  `GaussianMixtureClassifier.runit`(pointclouds) |
  `GaussianMixtureClassifier.score`(pointclouds, …) | Score predicted labels against known labels.
  `GaussianMixtureClassifier.set_params`(**params) | Set the parameters of this estimator.

#### Previous topic

multidim.models.CDER.set_params

#### Next topic

multidim.models.GaussianMixtureClassifier.evaluate